@@ -4,7 +4,7 @@ from asyncio import CancelledError
 from typing import TYPE_CHECKING, Any, List, Optional
 
 from ....jsonrpc2.protocol import rpc_method
-from ....utils.async_tools import async_tasking_event
+from ....utils.async_tools import async_tasking_event, threaded
 from ....utils.logging import LoggingDescriptor
 from ..decorators import language_id_filter
 from ..has_extend_capabilities import HasExtendCapabilities
@@ -43,6 +43,7 @@ class ReferencesProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         ...
 
     @rpc_method(name="textDocument/references", param_type=ReferenceParams)
+    @threaded()
     async def _text_document_references(
         self,
         text_document: TextDocumentIdentifier,
