@@ -16,14 +16,13 @@ from typing import (
     cast,
 )
 
-from robotcode.language_server.common.lsp_types import MessageType
-
 from ....utils.async_tools import Lock, async_tasking_event, check_canceled_sync
 from ....utils.uri import Uri
 from ...common.decorators import language_id_filter
+from ...common.lsp_types import MessageType
 from ...common.parts.workspace import WorkspaceFolder
 from ...common.text_document import TextDocument
-from ..configuration import RobotConfig
+from ..configuration import RobotCodeConfig, RobotConfig
 from ..diagnostics.imports_manager import ImportsManager
 from ..diagnostics.namespace import DocumentType, Namespace
 from ..utils.ast_utils import Token
@@ -429,13 +428,18 @@ class DocumentsCache(RobotLanguageServerProtocolPart):
                 self._default_imports_manager = ImportsManager(
                     self.parent,
                     Uri(self.parent.workspace.root_uri or "."),
-                    RobotConfig(args=(), python_path=[], env={}, variables={}),
+                    RobotCodeConfig(),
                 )
 
             return self._default_imports_manager
 
     async def get_imports_manager(self, document: TextDocument) -> ImportsManager:
-        folder = self.parent.workspace.get_workspace_folder(document.uri)
+        return await self.get_imports_manager_for_uri(document.uri)
+
+    async def get_imports_manager_for_uri(self, uri: Uri) -> ImportsManager:
+        return await self.get_imports_manager_for_workspace_folder(self.parent.workspace.get_workspace_folder(uri))
+
+    async def get_imports_manager_for_workspace_folder(self, folder: Optional[WorkspaceFolder]) -> ImportsManager:
         if folder is None:
             if len(self.parent.workspace.workspace_folders) == 1:
                 folder = self.parent.workspace.workspace_folders[0]
@@ -444,7 +448,7 @@ class DocumentsCache(RobotLanguageServerProtocolPart):
 
         async with self._imports_managers_lock:
             if folder not in self._imports_managers:
-                config = await self.parent.workspace.get_configuration(RobotConfig, folder.uri)
+                config = await self.parent.workspace.get_configuration(RobotCodeConfig, folder.uri)
 
                 self._imports_managers[folder] = ImportsManager(self.parent, folder.uri, config)
 
